@@ -4,6 +4,7 @@ from django.contrib import admin
 from mptt.admin import DraggableMPTTAdmin
 from djgentelella.models import MenuItem, Help, GentelellaSettings, Notification
 from djgentelella.utils import clean_cache
+from djgentelella.models import PermissionsCategoryManagement
 
 
 class MenuAdmin(DraggableMPTTAdmin):
@@ -28,5 +29,7 @@ class NotificationAdmin(admin.ModelAdmin):
 
 admin.site.register(MenuItem, MenuAdmin)
 admin.site.register(Help)
+admin.site.register(PermissionsCategoryManagement)
 admin.site.register(GentelellaSettings, GentelellaSettingsAdmin)
 admin.site.register(Notification, NotificationAdmin)
+
