@@ -1067,12 +1067,12 @@ function decore_select2 (data) {
     return $wrapper;
 }
 
-function load_date_range(instance) {
+function load_date_range(instance, format='DD/MM/YYYY') {
     var options = {
         'startDate': moment().startOf('hour'),
         'endDate': moment().startOf('hour').add(32, 'hour'),
         'locale': {
-            format: 'DD/MM/YYYY',
+            format: format,
         }
     };
     if ($(instance).val().length > 0) {
@@ -1081,20 +1081,20 @@ function load_date_range(instance) {
             "startDate": days[0],
             "endDate": days[1],
             'locale': {
-                format: 'DD/MM/YYYY',
+                format: format,
             }
         }
     }
     return options;
 }
-function load_datetime_range(instance) {
+function load_datetime_range(instance, format='DD/MM/YYYY HH:mm A') {
     var options = {
         'timePicker': true,
         'timePicker24Hour': true,
         'startDate': moment().startOf('hour'),
         'endDate': moment().startOf('hour').add(32, 'hour'),
         'locale': {
-            format: 'DD/MM/YYYY HH:mm A'
+            format: format
         }
     };
     if ($(instance).val().length > 0) {
@@ -1105,13 +1105,13 @@ function load_datetime_range(instance) {
             'startDate': days[0],
             'endDate': days[1],
             'locale': {
-                format: 'DD/MM/YYYY HH:mm A'
+                format: format
             }
         }
     }
     return options;
 }
-function load_date_range_custom(instance) {
+function load_date_range_custom(instance, format='DD/MM/YYYY') {
     var options = {
         startDate: moment().startOf('hour'),
         endDate: moment().startOf('hour').add(32, 'hour'),
@@ -1123,7 +1123,7 @@ function load_date_range_custom(instance) {
             'Last Month': [moment().subtract(1, 'month').startOf('month'), moment().subtract(1, 'month').endOf('month')]
         },
         locale: {
-            format: 'DD/MM/YYYY',
+            format: format,
         }
     }
     if ($(instance).val().length > 0) {
@@ -1132,20 +1132,117 @@ function load_date_range_custom(instance) {
             "startDate": days[0],
             "endDate": days[1],
             'ranges': {
-                'Last 7 Days': [moment(days[0], "DD/MM/YYYY").subtract(6, 'days'), moment(days[0], "DD/MM/YYYY")],
-                'Next Week': [moment(days[0], "DD/MM/YYYY"), moment(days[0], "DD/MM/YYYY").add(7, 'days')],
-                'Last 30 Days': [moment(days[0], "DD/MM/YYYY").subtract(29, 'days'), moment(days[0], "DD/MM/YYYY")],
-                'This Month': [moment(days[0], "DD/MM/YYYY").startOf('month'), moment(days[0], "DD/MM/YYYY").endOf('month')],
-                'Last Month': [moment(days[0], "DD/MM/YYYY").subtract(1, 'month').startOf('month'), moment(days[0], "DD/MM/YYYY").subtract(1, 'month').endOf('month')]
+                'Last 7 Days': [moment(days[0], format).subtract(6, 'days'), moment(days[0], format)],
+                'Next Week': [moment(days[0], format), moment(days[0], format).add(7, 'days')],
+                'Last 30 Days': [moment(days[0], format).subtract(29, 'days'), moment(days[0], format)],
+                'This Month': [moment(days[0], format).startOf('month'), moment(days[0], format).endOf('month')],
+                'Last Month': [moment(days[0], format).subtract(1, 'month').startOf('month'), moment(days[0], format).subtract(1, 'month').endOf('month')]
             },
             'locale': {
-                format: 'DD/MM/YYYY',
+                format: format,
             }
         }
     }
     return options;
 }
+function grid_slider(instance) {
+    let obj = $(instance[0]);
 
+    let to = obj.attr('data-from_max');
+
+    let from = obj.attr('data-from_min');
+
+    if ($("input[name=" + obj.attr('data-target-to') + "]").val() > 200) {
+        to = $("input[name=" + obj.attr('data-target-to') + "]").val()
+    }
+
+    if ($("input[name=" + obj.attr('data-target-from') + "]").val() > 200) {
+        from = $("input[name=" + obj.attr('data-target-from') + "]").val()
+    }
+
+    let option = {
+        'min': obj.attr('data-min'),
+        'max': obj.attr('data-max'),
+        'from': from,
+        'to': to,
+        'type': 'double',
+        'step': obj.attr('data-step'),
+        'prefix': obj.attr('data-prefix'),
+        'from_fixed': obj.attr('data-from_fixed') === 'true',
+        'to_fixed': obj.attr('data-to_fixed') === 'true',
+        'to_max': obj.attr('data-to_max'),
+        'hide_min_max': obj.attr('data-hide_min_max'),
+        'grid': true,
+        'onChange': function (data) {
+            $("input[name=" + obj.attr('data-target-from') + "]").val(data.from);
+            $("input[name=" + obj.attr('data-target-to') + "]").val(data.to);
+            console.log(obj.attr('data-target-to'));
+        }
+    }
+    return option;
+}
+function grid_slider_single(instance) {
+    let obj = $(instance[0]);
+
+
+    let from = obj.attr('data_from');
+
+    if ($("input[name=" + obj.attr('data-target') + "]").val() > 0) {
+        from = $("input[name=" + obj.attr('data-target') + "]").val()
+    }
+
+    let option = {
+        'min': obj.attr('data-min'),
+        'max': obj.attr('data-max'),
+        'from': from,
+        'type': 'single',
+        'prefix': obj.attr('data-prefix'),
+        'grid': true,
+        'onChange': function (data) {
+            $("input[name=" + obj.attr('data-target') + "]").val(data.from);
+        }
+    }
+    return option;
+}
+function date_grid_slider(instance) {
+
+    let obj = $(instance);
+    let input = $("input[name=" + obj.attr('data-target') + "]").val();
+
+    function dateToTS(date) {
+        return date.valueOf();
+    }
+
+    function tsToDate(ts) {
+        var lang = "en-US";
+        var d = new Date(ts);
+
+        return d.toLocaleDateString(lang, {
+            year: 'numeric',
+            month: 'long',
+            day: 'numeric',
+            hour: 'numeric',
+            minute: 'numeric',
+            hour12: false,
+
+
+        });
+    }
+
+    instance.ionRangeSlider({
+        type: "single",
+        hide_min_max: false,
+        min: dateToTS(new Date(obj.attr('data_min'))),
+        max: dateToTS(new Date(obj.attr('data_max'))),
+        from: dateToTS(new Date(input != undefined ? input : obj.attr('data_from'))),
+        prettify: tsToDate,
+        onChange: function (data) {
+            var day = new Date(data.from);
+            day = day.getFullYear() + "-" + (day.getMonth() + 1) + "-" + day.getDate() + " " + day.getHours() + ":" + day.getMinutes()
+            $("input[name=" + obj.attr('data-target') + "]").val(day);
+        }
+    })
+}
 
 
 function create_identifiers(items){
@@ -1178,3 +1275,59 @@ function showHideRelatedFormFields(instance){
         instance.trigger('change');
     }
 }
+
+function upload_files(callback, meta, file, image, video) {
+    var csrftoken = getCookie('csrftoken');
+    $.ajaxSetup({
+        beforeSend: function (xhr, settings) {
+                xhr.setRequestHeader("X-CSRFToken", csrftoken);
+        }
+    });
+    var formData;
+    formData = new FormData();
+    formData.append('file', file, file.name);
+
+    if (meta.filetype == 'image') {
+        $.ajax({
+            type: "POST",
+            url: image,
+            data: formData,
+            dataType: "json",
+            processData: false,
+            contentType: false,
+            success: function (response) {
+                console.log(response.link);
+                callback(response.link, { title: file.name });
+            }
+        });
+    }
+    if (meta.filetype == 'media') {
+        $.ajax({
+            type: "POST",
+            url: video,
+            data: formData,
+            dataType: "json",
+            processData: false,
+            contentType: false,
+            success: function (response) {
+                callback(response.link, { title: file.name });
+            }
+        });
+    }
+}
+
+function uploadFile(url_pages,file, editor) {
+    data = new FormData();
+    data.append("file", file);
+    $.ajax({
+        data: data,
+        type: "POST",
+        url: url_pages,
+        cache: false,
+        contentType: false,
+        processData: false,
+        success: function (url) {
+            $(editor).summernote('editor.insertImage',(location.origin +url.link).trim());
+        }
+    });
+}
