@@ -7,6 +7,7 @@ from django.forms import (PasswordInput as DJPasswordInput, FileInput as DJFileI
                           SelectDateWidget as DJSelectDateWidget, SplitDateTimeWidget as DJSplitDateTimeWidget)
 from django.forms.widgets import Input as DJInput
 from django.urls import reverse_lazy,reverse
+from django.utils import formats
 from django.utils.translation import gettext as _
 
 
@@ -40,6 +41,51 @@ class TextInput(Input):
     input_type = 'text'
     template_name = 'gentelella/widgets/text.html'
 
+class HiddenInput(Input):
+    input_type = 'hidden'
+    template_name = 'gentelella/widgets/text.html'
+
+
+def GridSlider(attrs={}):
+    class GridSlider(Input):
+        input_type = 'text'
+        template_name = 'gentelella/widgets/input.html'
+        extra_attrs = attrs.copy()
+
+        def __init__(self, attrs=None, extraskwargs=True):
+            attrs = update_kwargs(attrs, self.__class__.__name__)
+            if self.extra_attrs:
+                attrs.update(self.extra_attrs)
+            super().__init__(attrs)
+    return GridSlider
+
+
+def DateGridSlider(attrs={}):
+    class DateGridSlider(Input):
+        input_type = 'text'
+        template_name = 'gentelella/widgets/input.html'
+        extra_attrs = attrs.copy()
+
+        def __init__(self, attrs=None, extraskwargs=True):
+            attrs = update_kwargs(attrs, self.__class__.__name__)
+            if self.extra_attrs:
+                attrs.update(self.extra_attrs)
+            super().__init__(attrs)
+    return DateGridSlider
+
+def SingleGridSlider(attrs={}):
+    class SingleGridSlider(Input):
+        input_type = 'text'
+        template_name = 'gentelella/widgets/input.html'
+        extra_attrs = attrs.copy()
+
+        def __init__(self, attrs=None, extraskwargs=True):
+            attrs = update_kwargs(attrs, self.__class__.__name__)
+            if self.extra_attrs:
+                attrs.update(self.extra_attrs)
+            super().__init__(attrs)
+    return SingleGridSlider
+
 
 class NumberInput(Input):
     input_type = 'number'
@@ -120,7 +166,45 @@ class Textarea(DJTextarea):
         super().__init__(attrs)
 
 
-class DateInput(DJDateInput):
+class DateFormatConverter:
+    JS_FORMATS = {
+      '%A': 'dddd',                           #Weekday as locale’s full name: (In English: Sunday, .., Saturday)(Auf Deutsch: Sonntag, .., Samstag)
+      '%a': 'ddd',                            #Weekday abbreivated: (In English: Sun, .., Sat)(Auf Deutsch: So, .., Sa)
+      '%B': 'MMMM',                           #Month name: (In English: January, .., December)(Auf Deutsch: Januar, .., Dezember)
+      '%b': 'MMM',                            #Month name abbreviated: (In English: Jan, .., Dec)(Auf Deutsch: Jan, .., Dez)
+      '%c': 'ddd MMM DD HH:mm:ss YYYY',       #Locale’s appropriate date and time representation: (English: Sun Oct 13 23:30:00 1996)(Deutsch: So 13 Oct 22:30:00 1996)
+      '%d': 'DD',                             #Day 0 padded: (01, .., 31)
+      '%f': 'SSS',                            #Microseconds 0 padded: (000000, .., 999999)
+      '%H': 'HH',                             #Hour (24-Hour) 0 padded: (00, .., 23)
+      '%I': 'hh',                             #Hour (12-Hour) 0 padded: (01, .., 12)
+      '%j': 'DDDD',                           #Day of Year 0 padded: (001, .., 366)
+      '%M': 'mm',                             #Minute 0 padded: (01, .. 59)
+      '%m': 'MM',                             #Month 0 padded: (01, .., 12)
+      '%p': 'A',                              #Locale equivalent of AM/PM: (EN: AM, PM)(DE: am, pm)
+      '%S': 'ss',                             #Second 0 padded: (00, .., 59)
+      '%U': 'ww',                             #Week  of Year (Sunday): (00, .., 53)  All days in a new year preceding the first Sunday are considered to be in week 0.
+      '%W': 'ww',                             #Week  of Year (Monday): (00, .., 53)  All days in a new year preceding the first Monday are considered to be in week 0.
+      '%w': 'd',                              #Weekday as : (0, 6)
+      '%X': 'HH:mm:ss',                       #Locale's appropriate time representation: (EN: 23:30:00)(DE: 23:30:00)
+      '%x': 'MM/DD/YYYY',                     #Locale's appropriate date representation: (None: 02/14/16)(EN: 02/14/16)(DE: 14.02.16)
+      '%Y': 'YYYY',                           #Year as : (1970, 2000, 2038, 292,277,026,596)
+      '%y': 'YY',                             #Year without century 0 padded: (00, .., 99)
+      '%Z': 'z',                              #Time zone name: ((empty), UTC, EST, CST) (empty string if the object is naive).
+      '%z': 'ZZ',                             #UTC offset in the form +HHMM or -HHMM: ((empty), +0000, -0400, +1030) Empty string if the the object is naive.
+      '%%': '%'                               #A literal '%' character: (%)
+    }
+
+    def convert_python_to_js(self, value):
+        for key in self.JS_FORMATS:
+            js_key=self.JS_FORMATS[key]
+            value = js_key.join(value.split(key))
+        return value
+
+    def get_format_js(self):
+        self.format = formats.get_format(self.format_key)[0]
+        return self.convert_python_to_js(self.format)
+
+class DateInput(DJDateInput, DateFormatConverter):
     """
     .. warning::
         Set in settings
@@ -136,10 +220,12 @@ class DateInput(DJDateInput):
 
     def __init__(self, attrs=None, format=None):
         attrs = update_kwargs(attrs, self.__class__.__name__)
-        super().__init__(attrs, format=format)
+        format_js = self.get_format_js()
+        attrs['data-format'] = format_js
+        super().__init__(attrs, format=format or self.format)
 
 
-class DateTimeInput(DJDateTimeInput):
+class DateTimeInput(DJDateTimeInput, DateFormatConverter):
     """
     .. warning::
         Set in settings
@@ -156,18 +242,20 @@ class DateTimeInput(DJDateTimeInput):
 
     def __init__(self, attrs=None, format=None):
         attrs = update_kwargs(attrs, self.__class__.__name__)
-        super().__init__(attrs, format=format)
+        format_js = self.get_format_js()
+        attrs['data-format'] = format_js
+        super().__init__(attrs, format or self.format)
 
 
-class TimeInput(DJTimeInput):
+class TimeInput(DJTimeInput, DateFormatConverter):
     format_key = 'TIME_INPUT_FORMATS'
     template_name = 'gentelella/widgets/time.html'
 
     def __init__(self, attrs=None, format=None):
         attrs = update_kwargs(attrs, self.__class__.__name__)
-        super().__init__(attrs, format=format)
-        self.format = format or "%H:%M:%S"
-
+        format_js = self.get_format_js()
+        attrs['data-format'] = format_js
+        super().__init__(attrs, format or self.format)
 
 class CheckboxInput(DJCheckboxInput):
     input_type = 'checkbox'
@@ -390,6 +478,7 @@ class DateRangeInput(DJDateInput):
         attrs = update_kwargs(attrs, self.__class__.__name__)
         super().__init__(attrs, format=format)
 
+
 class DateRangeInputCustom(DJDateInput):
     format_key = 'DATE_INPUT_FORMATS'
     template_name = 'gentelella/widgets/daterange.html'
@@ -398,31 +487,34 @@ class DateRangeInputCustom(DJDateInput):
         attrs = update_kwargs(attrs, self.__class__.__name__)
         super().__init__(attrs, format=format)
 
+
 class SerialNumberMaskInput(TextInput):
-    input_type='text'
-    template_name='gentelella/widgets/input_mask.html'
-    
+    input_type = 'text'
+    template_name = 'gentelella/widgets/input_mask.html'
+
     def __init__(self, attrs=None, format=None):
         attrs = update_kwargs(attrs, self.__class__.__name__)
         super().__init__(attrs)
 
 
 class TaxIDMaskInput(TextInput):
-    input_type='text'
-    template_name='gentelella/widgets/input_mask.html'
-    
+    input_type = 'text'
+    template_name = 'gentelella/widgets/input_mask.html'
+
     def __init__(self, attrs=None, format=None):
         attrs = update_kwargs(attrs, self.__class__.__name__)
         super().__init__(attrs)
-        
+
+
 class CreditCardMaskInput(TextInput):
-    input_type='text'
-    template_name='gentelella/widgets/input_mask.html'
-    
+    input_type = 'text'
+    template_name = 'gentelella/widgets/input_mask.html'
+
     def __init__(self, attrs=None, format=None):
         attrs = update_kwargs(attrs, self.__class__.__name__)
         super().__init__(attrs)
-        
+
+
 class PhoneNumberTwoDigitMaskInput(TextInput):
     input_type = 'text'
     template_name = 'gentelella/widgets/phone_number_input_mask.html'
@@ -432,6 +524,7 @@ class PhoneNumberTwoDigitMaskInput(TextInput):
 
         super().__init__(attrs)
 
+
 class PhoneNumberMaskInput(TextInput):
     input_type = 'text'
     template_name = 'gentelella/widgets/phone_number_input_mask.html'
@@ -440,4 +533,3 @@ class PhoneNumberMaskInput(TextInput):
         attrs = update_kwargs(attrs, self.__class__.__name__)
 
         super().__init__(attrs)
-
